@@ -20,11 +20,12 @@ class Aladhan:
         Note: If `default_location` is not provided, it will be required for every method.
         """
         self.default_location = default_location
-    
-    def get_calendar(
+
+    def get_prayer_times(
         self, 
         location: Union[Coordinates, Address, City] = None, 
         year: int=None, month: int=None,
+        today_only=False
     ) -> list[Adhan]:
         """
         Get the prayer times for a specific month (current month by default) and returns a list of `adhan_api.Adhan` objects.
@@ -45,14 +46,7 @@ class Aladhan:
                 raise ValueError('No location was provided.')
             else:
                 location = self.default_location
-        
-        # figure out the year and month if they were in the argument or not
-        if year and month:
-            params['year'] = year
-            params['month'] = month
-        if (year and not month) or (month and not year):
-            raise ValueError('Both year and month must be provided.')
-        
+
         # get the location type and the ENDPOINT
         if isinstance(location, Coordinates):
             ENDPOINT = 'calendar'
@@ -69,23 +63,39 @@ class Aladhan:
                 params['state'] = location.state
         else:
             raise TypeError('Invalid location type.')
-
+        
+        # today only
+        if today_only:
+            ENDPOINT = ENDPOINT.replace('calendar', 'timings')
+        
         # send the request and get the JSON data
         response = requests.get(API + ENDPOINT, params=params)
         data = response.json()
-        
+
         # loop through the data and create a list of Adhan objects
-        adhan_list = []
-        for day in data['data']:
-
-            date = datetime.strptime(day['date']['gregorian']['date'], '%d-%m-%Y')
-
-            for salah_name, salah_time in day['timings'].items():
+        
+        # for entire month
+        if not today_only:
+            adhan_list = []
+            for day in data['data']:
+                date = datetime.strptime(day['date']['gregorian']['date'], '%d-%m-%Y')
+                for salah_name, salah_time in day['timings'].items():
+                    if salah_name in ['Sunrise', 'Sunset', 'Midnight', 'Lastthird', 'Firstthird', 'Imsak']:
+                        continue
+                    salah_time = datetime.strptime(salah_time.split(" ")[0], '%H:%M')
+                    salah_time = salah_time.replace(year=date.year, month=date.month, day=date.day)
+                    adhan_list.append(Adhan(salah_name, salah_time))
+            return adhan_list
+        
+        # for today only
+        else:
+            adhan_list = []
+            date = datetime.now()
+            for salah_name, salah_time in data['data']['timings'].items():
                 if salah_name in ['Sunrise', 'Sunset', 'Midnight', 'Lastthird', 'Firstthird', 'Imsak']:
                     continue
                 salah_time = datetime.strptime(salah_time.split(" ")[0], '%H:%M')
                 salah_time = salah_time.replace(year=date.year, month=date.month, day=date.day)
                 adhan_list.append(Adhan(salah_name, salah_time))
-
-        return adhan_list
+            return adhan_list
 
